package com.fs.oms.service;

import java.util.List;
import com.fs.oms.domain.OmsStore;
import com.fs.oms.param.OmsStoreAddParam;
import com.fs.oms.vo.OmsStoreVO;

/**
 * 网店Service接口
 *
 * @author fs
 * @date 2023-05-18
 */
public interface IOmsStoreService
{
    /**
     * 查询网店
     *
     * @param storeId 网店ID
     * @return 网店
     */
    public OmsStore selectOmsStoreById(Long storeId);

    /**
     * 查询网店列表
     *
     * @param omsStore 网店
     * @return 网店集合
     */
    public List<OmsStore> selectOmsStoreList(OmsStore omsStore);

    /**
     * 查询网店列表
     *
     * @param omsStore 网店
     * @return 网店集合
     */
    public List<OmsStoreVO> selectOmsStoreListVO(OmsStore omsStore);

    /**
     * 新增网店
     *
     * @param omsStore 网店
     * @return 结果
     */
    public int insertOmsStore(OmsStoreAddParam omsStore,Long userId);

    /**
     * 修改网店
     *
     * @param omsStore 网店
     * @return 结果
     */
    public int updateOmsStore(OmsStoreAddParam omsStore);

    /**
     * 批量删除网店
     *
     * @param storeIds 需要删除的网店ID
     * @return 结果
     */
    public int deleteOmsStoreByIds(Long[] storeIds);

    /**
     * 删除网店信息
     *
     * @param storeId 网店ID
     * @return 结果
     */
    public int deleteOmsStoreById(Long storeId);
}
